@@ -6,7 +6,7 @@ use Authen::Simple::Password;
 use Authen::Simple::Passwd;
 use Authen::Simple::LDAP;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub register {
     my ( $plugin, $app ) = @_;
@@ -29,9 +29,9 @@ sub register {
                     and !$callback
                     and !$params;
 
-            # Hash to hold return data
+            # Hash for return data
             my %data;
-            $data{username} = $username;
+            $data{username} = $username if $username;
 
             # Verification within callback
             return (\%data, 1)
@@ -44,6 +44,7 @@ sub register {
             # Verified via simple, passwd file, LDAP, or Active Directory.
             if ($auth) {
                 if ( $params->{'username'} and $params->{'password'} ) {
+                    $data{username} = $params->{'username'};
                     return (\%data, 1)
                         if $plugin->_check_simple( $self, $auth, $params );
                 }
@@ -131,7 +132,7 @@ Mojolicious::Plugin::BasicAuthPlus - Basic HTTP Auth Helper Plus
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
